# PyLUSAT
Python Land-Use Suitability Analysis Toolkit

## Introduction
PyLUSAT intends to provide users with tools that can be used to conduct land-use 
suitability analysis.

## Install
PyLUSAT depends on the following packages.
- geopandas
- rasterio
- rasterstats
- scipy
